### Name: est.rr
### Title: Estimates Relative Risk
### Aliases: est.rr
### Keywords: htest

### ** Examples


        data(gradData)
        aa<-est.rr(Count|Admitted~.,data=gradData,indexed=TRUE)
        names(aa)
        aa$log
        aa$table

        aa<-est.rr(Count | Admitted ~.,data=gradData,indexed=TRUE,doLog=FALSE)
        aa$table

        # Simpson's paradox, since the observed relative risks for Males in each department
        # tend to be greater than unity, while the overal all risk is less than unity.
        aa<-est.rr(Count|Admitted~Dept*Male,indexed=TRUE,data=gradData)
        aa$table

        # Convergence difficulties example:
        data(TitanicMat)
        # Reverse the sex variable
        TitanicMatR<-as.twolevel("sex",TitanicMat,1)
        # glm() fails to converge upon reversing the variable.
        # Dropping the Age variable allows convergence in this particular case.
        # as including information in the log.
        aa<-est.rr(count|survived~.,indexed=TRUE,data=TitanicMat)
        at<-est.rr(count|survived~.,indexed=TRUE,data=TitanicMatR)
        aa$table
        at$table

        # Interpreting factors example:
        # The relative risks are for cancer, and the factors are all compared 
        # to their most extreme level: tobacco for example is compared to the heaviest users.
        # This is case-control data, and since cancer is rare, theta should be large, which
        # tends to make the relative risks the same as the odds ratios.
        aa<-est.rr(ncases|ncontrols~.,esoph,theta=1000)
        aa$table

        # Retrospective sampling example with 600 Cases and 300 Controls. 
        # The true relative risks are (0.3,1.5,2.0,0.7,0.3)
        data(simData)
        aa<-est.rr(Success|Failure~.,data=simData,theta=2.2)
        aa$table

        # Very large odds raio:
        data(Melanoma)
        aa<-est.rr(NarrowExc|WideExc~.,Melanoma)
        aa$table




